"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("../mongoose/model-config");
const _ = require("underscore");
const dotty = require('dotty');
function overrides(...rules) {
    const rs = [];
    for (const rule of rules) {
        const [os, od] = rule.split('->');
        if (!od) {
            throw new Error(`Rule ${rule} is not correct`);
        }
        rs.push({ src: split(os), dst: split(od) });
    }
    return async (ctx, next) => {
        for (const { src, dst } of rs) {
            const value = dotty.get(ctx, src);
            if (value !== undefined) {
                dotty.put(ctx, ['overrides'].concat(dst), value);
            }
        }
        await next();
    };
}
exports.overrides = overrides;
function clearOverrides() {
    return async (ctx, next) => {
        ctx.overrides = {
            query: {},
            doc: {},
        };
        await next();
    };
}
exports.clearOverrides = clearOverrides;
function split(str) {
    const strs = str.split('.');
    for (let i = strs.length - 1; i >= 1; i--) {
        if (strs[i - 1].endsWith('\\')) {
            strs[i - 1] =
                strs[i - 1].substring(0, strs[i - 1].length - 1) + '.' + strs[i];
            strs[i] = '';
        }
    }
    return _.filter(strs, x => !!x);
}

//# sourceMappingURL=overrides.js.map
